@@ -23,6 +23,13 @@ def pipein():
         return pd.DataFrame()
 
 
+@register
+def date(col):
+    df = pipein()
+    df[col] = pd.to_datetime(df[col])
+    pipeout(df)
+
+
 @register
 def describe():
     print(pipein().describe())
